API Reference
#############

Application programming interface of geonum.

.. _geopoint:

Specifying locations on Earth
=============================

.. automodule:: geonum.geopoint
   :members:
   :undoc-members:

.. _geovector:

Connecting the dots
===================

.. automodule:: geonum.geovector3d
   :members:
   :undoc-members:

.. _geosetup:

Working with geographical domains
=================================

.. automodule:: geonum.geosetup
   :members:
   :undoc-members:

.. _elevationprofiles:

Computing elevation profiles
============================

.. automodule:: geonum.elevationprofile
   :members:
   :undoc-members:

Further tools
========================

Line on grid
------------

.. automodule:: geonum.lineongrid
   :members:
   :undoc-members:

.. _topodata:

Topographic data
================

Access to topographic data
--------------------------

.. automodule:: geonum.topodataaccess
   :members:
   :undoc-members:

Topographic data class
----------------------

.. automodule:: geonum.topodata
   :members:
   :undoc-members:

Low-level access and template classes
-------------------------------------

.. automodule:: geonum.topoaccessbase
   :members:
   :undoc-members:

.. _atmosphere:

Atmospheric calculations
========================

.. automodule:: geonum.atmosphere
   :members:
   :undoc-members:

Helper methods
==============

.. automodule:: geonum.helpers
   :members:
   :undoc-members:

Utility functions
=================

.. automodule:: geonum.utils
   :members:
   :undoc-members:

Plotting
========

.. automodule:: geonum.plot_helpers
   :members:
   :undoc-members:

DEPRECATED: mapping.py
-----------------------

.. note::

  The former map plotting routines routines (:mod:`geonum.mapping`)
  are deprecated as they are based on the basemap library. They
  will be revised and replaced in parts using cartopy. For details see:
  https://github.com/jgliss/geonum/issues/4

.. automodule:: geonum.mapping
   :members:
   :undoc-members:

Custom exceptions
=================

.. automodule:: geonum.exceptions
   :members:
   :undoc-members: